@@ -11,11 +11,11 @@
 # of the BSD license.  See the LICENSE file for details.
 import functools
 import gc
+import logging
 import math
-from concurrent.futures import ProcessPoolExecutor as Pool
-from copy import deepcopy
-from functools import partial
 import re
+from concurrent.futures import ProcessPoolExecutor as Pool
+from functools import partial
 from typing import List, Union, Tuple
 
 import more_itertools
@@ -38,6 +38,8 @@ from kss.base import (
 )
 from kss.rule import Table, Stats, ID
 
+NOTICE_MECAB = False
+
 
 def split_sentences(
     text: Union[str, tuple, List[str]],
@@ -45,8 +47,8 @@ def split_sentences(
     use_quotes_brackets_processing: bool = False,
     max_recover_step: int = 5,
     max_recover_length: int = 20000,
-    backend: str = "pynori",
-    num_workers: int = -1,
+    backend: str = "auto",
+    num_workers: int = "auto",
     disable_gc: bool = True,
     disable_mp_post_process: bool = False,
 ) -> Union[List[str], List[List[str]]]:
@@ -68,14 +70,38 @@ def split_sentences(
         Union[List[str], List[List[str]]]: list of segmented sentences
     """
     assert isinstance(backend, str), "param `backend` must be `str` type"
-
     backend = backend.lower()
 
     assert backend in [
         "pynori",
         "mecab",
         "none",
-    ], "Wrong backend! Currently, we support [`pynori`, `mecab`, `none`] backend."
+        "auto",
+    ], "Wrong backend! Currently, we support [`pynori`, `mecab`, `none`, `auto`] backend."
+
+    if backend == "auto":
+        try:
+            import mecab
+
+            backend = "mecab"
+        except ImportError:
+            import platform
+
+            global NOTICE_MECAB
+            if platform.uname().system in ["Darwin", "Linux"]:
+                logging.warning(
+                    "You can install `python-mecab-kor` for faster kss execution. "
+                    "Try to install it using `pip install python-mecab-kor`."
+                )
+                NOTICE_MECAB = True
+
+            backend = "pynori"
+
+    if num_workers == "auto":
+        if isinstance(text, str):
+            num_workers = 1
+        else:
+            num_workers = -1
 
     if backend == "pynori":
         _morph.create_pynori()
@@ -99,6 +125,9 @@ def split_sentences(
     if disable_gc:
         gc.disable()
 
+    if isinstance(text, str) and "\n" not in text:
+        num_workers = 1
+
     num_workers = get_num_workers(num_workers)
     results = []
 
@@ -119,7 +148,7 @@ def split_sentences(
         pool = Pool(max_workers=num_workers)
 
     if pool:
-        preprocessed_list = pool.map(build_preprocessed_list, _text)
+        preprocessed_list = list(pool.map(build_preprocessed_list, _text))
     else:
         preprocessed_list = [build_preprocessed_list(t) for t in _text]
 
@@ -128,12 +157,8 @@ def split_sentences(
             input_text.append("")
 
     mp_temp = preprocessed_list
-    mp_input_texts = more_itertools.flatten(preprocessed_list)
-
-    if use_quotes_brackets_processing:
-        pattern = re.compile(f"[{''.join(Const.quotes_or_brackets)}]+")
-    else:
-        pattern = re.compile("[ ]+")
+    mp_input_texts = list(more_itertools.flatten(preprocessed_list))
+    pattern = re.compile("[ ]+")
 
     if not disable_mp_post_process:
         mp_postprocessing = list(map(lambda x: pattern.sub("", "".join(x)), mp_temp))
@@ -167,11 +192,7 @@ def split_sentences(
     mp_temp.clear()
     _results = clear_list_to_sentences(results)
 
-    if not disable_mp_post_process:
-        if use_quotes_brackets_processing:
-            pattern = re.compile("[\u200b]+")
-            mp_postprocessing = list(map(lambda x: pattern.sub("", x), mp_postprocessing))
-
+    if pool and not disable_mp_post_process:
         for result in _results:
             mp_temp += result
             out = pattern.sub("", "".join(mp_temp))
